Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
committerJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
commit9bb7d6ed68ef1aa0e6acc3e70901cb6b79c682d2 (patch)
tree843993222b8ee5c02451207404ceb113323ede6f /source/blender/blenlib/BLI_set_slots.hh
parentd8678e02ecec9375bec1dcf1388c6fc8b4ce3ad2 (diff)
BLI: put C++ data structures in "blender" namespace instead of "BLI"
We plan to use the "blender" namespace in other modules as well.
Diffstat (limited to 'source/blender/blenlib/BLI_set_slots.hh')
-rw-r--r--source/blender/blenlib/BLI_set_slots.hh6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/blenlib/BLI_set_slots.hh b/source/blender/blenlib/BLI_set_slots.hh
index 21493524bd8..15f56f2450e 100644
--- a/source/blender/blenlib/BLI_set_slots.hh
+++ b/source/blender/blenlib/BLI_set_slots.hh
@@ -20,7 +20,7 @@
/** \file
* \ingroup bli
*
* This file contains different slot types that are supposed to be used with BLI::Set.
*
* Every slot type has to be able to hold a value of the Key type and state information.
* A set slot has three possible states: empty, occupied and removed.
@@ -35,7 +35,7 @@
#include "BLI_memory_utils.hh"
#include "BLI_string_ref.hh"
-namespace BLI {
+namespace blender {
/**
* The simplest possible set slot. It stores the slot state and the optional key instance in
@@ -410,6 +410,6 @@ template<typename Key> struct DefaultSetSlot<Key *> {
using type = IntrusiveSetSlot<Key *, PointerKeyInfo<Key *>>;
};
-} // namespace BLI
+} // namespace blender
#endif /* __BLI_SET_SLOTS_HH__ */
@@ -20,7 +20,7 @@
* \ingroup bli
*
- * This file contains different slot types that are supposed to be used with BLI::Set.
+ * This file contains different slot types that are supposed to be used with blender::Set.
*
* Every slot type has to be able to hold a value of the Key type and state information.